==> laktory-0.5.11.tar.gz: laktory-0.5.11/laktory/models/resources/databricks/groupmember.py <==
from laktory.models.basemodel import BaseModel
from laktory.models.resources.pulumiresource import PulumiResource
from laktory.models.resources.terraformresource import TerraformResource


class GroupMember(BaseModel, PulumiResource, TerraformResource):
    """
    Databricks secret ACL

    Attributes
    ----------
    group_id:
        This is the id of the group resource.
    member_id:
        This is the id of the group, service principal, or user.
    """

    group_id: str = None
    member_id: str = None

    # ----------------------------------------------------------------------- #
    # Resource Properties                                                     #
    # ----------------------------------------------------------------------- #

    @property
    def resource_key(self) -> str:
        return f"{self.group_id}-{self.member_id}"

    # ----------------------------------------------------------------------- #
    # Pulumi Properties                                                       #
    # ----------------------------------------------------------------------- #

    @property
    def pulumi_resource_type(self) -> str:
        return "databricks:GroupMember"

    # ----------------------------------------------------------------------- #
    # Terraform Properties                                                    #
    # ----------------------------------------------------------------------- #

    @property
    def terraform_resource_type(self) -> str:
        return "databricks_group_member"

==> laktory-0.8.4.tar.gz: laktory-0.8.4/laktory/models/resources/databricks/groupmember.py <==
from pydantic import Field

from laktory.models.basemodel import BaseModel
from laktory.models.resources.pulumiresource import PulumiResource
from laktory.models.resources.terraformresource import TerraformResource


class GroupMember(BaseModel, PulumiResource, TerraformResource):
    """
    Databricks secret ACL
    """

    group_id: str = Field(None, description="This is the id of the group resource.")
    member_id: str = Field(
        None, description="This is the id of the group, service principal, or user."
    )

    # ----------------------------------------------------------------------- #
    # Resource Properties                                                     #
    # ----------------------------------------------------------------------- #

    @property
    def resource_key(self) -> str:
        return f"{self.group_id}-{self.member_id}"

    # ----------------------------------------------------------------------- #
    # Pulumi Properties                                                       #
    # ----------------------------------------------------------------------- #

    @property
    def pulumi_resource_type(self) -> str:
        return "databricks:GroupMember"

    # ----------------------------------------------------------------------- #
    # Terraform Properties                                                    #
    # ----------------------------------------------------------------------- #

    @property
    def terraform_resource_type(self) -> str:
        return "databricks_group_member"
